@@ -75,7 +75,14 @@ const RootPidStore *PidStoreLoader::LoadFromDirectory(
 
   string override_file;
   vector<string> all_files;
-  ola::file::ListDirectory(directory, &all_files);
+  if (!ola::file::ListDirectory(directory, &all_files)) {
+    OLA_WARN << "Failed to list files in " << directory;
+    return NULL;
+  }
+  if (all_files.empty()) {
+    OLA_WARN << "Didn't find any files in " << directory;
+    return NULL;
+  }
   vector<string>::const_iterator file_iter = all_files.begin();
   for (; file_iter != all_files.end(); ++file_iter) {
     if (ola::file::FilenameFromPath(*file_iter) == OVERRIDE_FILE_NAME) {
@@ -84,6 +91,10 @@ const RootPidStore *PidStoreLoader::LoadFromDirectory(
       files.push_back(*file_iter);
     }
   }
+  if (files.empty() && override_file.empty()) {
+    OLA_WARN << "Didn't find any files to load in " << directory;
+    return NULL;
+  }
 
   ola::rdm::pid::PidStore pid_store_pb;
   vector<string>::const_iterator iter = files.begin();
@@ -483,16 +494,16 @@ const FieldDescriptor *PidStoreLoader::IntegerFieldToFieldDescriptor(
     }
   }
 
-  int8_t multipler = 0;
+  int8_t multiplier = 0;
   if (field.has_multiplier())
-    multipler = field.multiplier();
+    multiplier = field.multiplier();
 
   return new descriptor_class(
       field.name(),
       intervals,
       labels,
       false,
-      multipler);
+      multiplier);
 }
 
 /*
