@@ -15,6 +15,7 @@
 # ModelCollector.py
 # Copyright (C) 2011 Simon Newton
 
+from __future__ import print_function
 import logging
 import ola.RDMConstants
 from ola import PidStore
@@ -248,6 +249,7 @@ class ModelCollector(object):
     this_version = self._GetVersion()
     this_version['manufacturer_pids'].append({
       'pid': data['pid'],
+      'pdl_size': data['pdl_size'],
       'description': data['description'],
       'command_class': data['command_class'],
       'data_type': data['data_type'],
@@ -506,11 +508,11 @@ class ModelCollector(object):
     # description for every slot
     if (response.response_type == OlaClient.RDM_NACK_REASON and
         response.pid != self.pid_store.GetName('SLOT_DESCRIPTION').value):
-      print ('Got nack with reason for pid %s: %s' %
-             (response.pid, response.nack_reason))
+      print('Got nack with reason for pid %s: %s' %
+            (response.pid, response.nack_reason))
       self._NextState()
     elif unpack_exception:
-      print unpack_exception
+      print(unpack_exception)
       self.wrapper.Stop()
     else:
       self._HandleResponse(unpacked_data)
@@ -534,11 +536,11 @@ class ModelCollector(object):
         logging.debug('Device doesn\'t support queued messages')
         self._NextState()
       else:
-        print 'Got nack for 0x%04hx with reason: %s' % (
-            response.pid, response.nack_reason)
+        print('Got nack for 0x%04hx with reason: %s' %
+              (response.pid, response.nack_reason))
 
     elif unpack_exception:
-      print 'Invalid Param data: %s' % unpack_exception
+      print('Invalid Param data: %s' % unpack_exception)
       self.queued_message_failures += 1
       if self.queued_message_failures >= 10:
         # declare this bad and move on
@@ -571,12 +573,12 @@ class ModelCollector(object):
       True if this response was an ACK or NACK, False for all other cases.
     """
     if not response.status.Succeeded():
-      print response.status.message
+      print(response.status.message)
       self.wrapper.Stop()
       return False
 
     if response.response_code != OlaClient.RDM_COMPLETED_OK:
-      print response.ResponseCodeAsString()
+      print(response.ResponseCodeAsString())
       self.wrapper.Stop()
       return False
 
