@@ -16,6 +16,7 @@
 # rdm_test_server.py
 # Copyright (C) 2012 Ravindra Nath Kakarla & Simon Newton
 
+from __future__ import print_function
 import cgi
 import json
 import logging
@@ -465,7 +466,7 @@ class StaticFileHandler(RequestHandler):
 
     # Strip off /static
     path = path[len(self.PREFIX):]
-    # This is important as it ensures we can't access arbitary files
+    # This is important as it ensures we can't access arbitrary files
     filename = os.path.abspath(os.path.join(self._static_dir, path))
     if (not filename.startswith(self._static_dir) or
          not os.path.exists(filename) or
@@ -623,7 +624,7 @@ class DownloadModelDataHandler(RequestHandler):
   """Take the data in the form and return it as a downloadable file."""
 
   def HandleRequest(self, request, response):
-    print dir(request)
+    print(dir(request))
     model_data = request.PostParam('model_data') or ''
     logging.info(model_data)
 
@@ -816,7 +817,7 @@ class RunTestsHandler(OLAServerRequestHandler):
     return {'status': True}
 
   def _CheckValidUniverse(self, request):
-    """Check that the universe paramter is present and refers to a valid
+    """Check that the universe parameter is present and refers to a valid
        universe.
 
     Args:
@@ -958,7 +959,7 @@ def BuildApplication(ola_thread, test_thread):
   app.RegisterHandler('/RunTests', run_tests_handler.HandleRequest)
   app.RegisterHandler('/StatCollector', run_tests_handler.HandleRequest)
   app.RegisterHandler('/StatTests', run_tests_handler.HandleRequest)
-  app.RegisterRegex('/static/.*',
+  app.RegisterRegex(r'/static/.*',
                     StaticFileHandler(settings['www_dir']).HandleRequest)
   return app
 
@@ -980,7 +981,8 @@ def parse_options():
   parser.add_option('-p', '--pid-location', metavar='DIR',
                     help='The directory to load the PID definitions from.')
   parser.add_option('-d', '--www-dir', default=DataLocation.location,
-                    help='The root directory to serve static files.')
+                    help='The root directory to serve static files, this must '
+                         'be absolute.')
   parser.add_option('-l', '--log-directory',
                     default=os.path.abspath('/tmp/ola-rdm-logs'),
                     help='The directory to store log files.')
@@ -1041,7 +1043,7 @@ def main():
   app = BuildApplication(ola_thread, test_thread)
 
   httpd = make_server('', settings['PORT'], app.HandleRequest)
-  logging.info('Running RDM Tests Server on %s:%s' %
+  logging.info('Running RDM Tests Server on http://%s:%s' %
                ('127.0.0.1', httpd.server_port))
 
   try:
