@@ -116,7 +116,7 @@ RDMTests.publisher_url = 'http://rdm.openlighting.org/incoming/model_data';
 /**
  * Prepares the notification div and displays it on the page.
  * @this {RDMTests}
- * @param {Objec} options An object containing title and message to be
+ * @param {Object} options An object containing title and message to be
  * displayed.
  *
  *  {
@@ -297,10 +297,10 @@ RDMTests.prototype.save_results = function() {
   var url = ('/DownloadResults?uid=' + uid + '&timestamp=' + this.timestamp +
              '&state=' + $('#rdm-tests-save-state').val() + '&category=' +
              $('#rdm-tests-save-catg').val());
-  if ($('#rdm-tests-include-debug').attr('checked')) {
+  if ($('#rdm-tests-include-debug').prop('checked')) {
     url += '&debug=1';
   }
-  if ($('#rdm-tests-include-description').attr('checked')) {
+  if ($('#rdm-tests-include-description').prop('checked')) {
     url += '&description=1';
   }
   $('#rdm-tests-download').attr('src', url);
@@ -493,7 +493,7 @@ RDMTests.prototype.update_device_list = function() {
  * Called when the selected device changes.
  */
 RDMTests.prototype.device_list_changed = function() {
-  $('#rdm-tests-selection-subset').attr('checked', true);
+  $('#rdm-tests-selection-subset').prop('checked', true);
   this._reset_failed_tests_list();
 };
 
@@ -539,9 +539,9 @@ RDMTests.prototype.run_tests = function(test_filter) {
           'uid': $('#devices_list').val(),
           'broadcast_write_delay': $('#write_delay').val(),
           'inter_test_delay': $('#inter_test_delay').val(),
-          'dmx_frame_rate': ($('#rdm-tests-send_dmx_in_bg').attr('checked') ?
+          'dmx_frame_rate': ($('#rdm-tests-send_dmx_in_bg').prop('checked') ?
                              $('#dmx_frame_rate').val() : 0),
-          'slot_count': ($('#rdm-tests-send_dmx_in_bg').attr('checked') ?
+          'slot_count': ($('#rdm-tests-send_dmx_in_bg').prop('checked') ?
                          $('#slot_count').val() : 0),
           't': test_filter.join(',')
       },
@@ -771,7 +771,7 @@ RDMTests.prototype.validate_form = function() {
     }
   };
 
-  if ($('#devices_list option').size() < 1) {
+  if ($('#devices_list option').length < 1) {
     rdmtests.display_dialog_message(
         'Error',
         'There are no devices patched to the selected universe!');
@@ -780,7 +780,7 @@ RDMTests.prototype.validate_form = function() {
 
   if (!this.isNumberField($('#write_delay')) ||
       !this.isNumberField($('#inter_test_delay')) ||
-      ($('#rdm-tests-send_dmx_in_bg').attr('checked') &&
+      ($('#rdm-tests-send_dmx_in_bg').prop('checked') &&
        (!this.isNumberField($('#dmx_frame_rate')) ||
         !this.isNumberField($('#slot_count'))))) {
     rdmtests.display_dialog_message('Error', 'Invalid options entered');
@@ -788,7 +788,7 @@ RDMTests.prototype.validate_form = function() {
   }
 
   var slot_count_val = parseFloat($('#slot_count').val());
-  if ($('#rdm-tests-send_dmx_in_bg').attr('checked') &&
+  if ($('#rdm-tests-send_dmx_in_bg').prop('checked') &&
       (slot_count_val < 1 || slot_count_val > 512)) {
     rdmtests.display_dialog_message(
         'Error',
@@ -798,7 +798,7 @@ RDMTests.prototype.validate_form = function() {
 
   var test_filter = ['all'];
 
-  if ($('#rdm-tests-selection-subset').attr('checked')) {
+  if ($('#rdm-tests-selection-subset').prop('checked')) {
     if ($('select[name="subset_test_defs"]').val() == null) {
       rdmtests.display_dialog_message('Error',
                                       'There are no tests selected to run');
@@ -806,7 +806,7 @@ RDMTests.prototype.validate_form = function() {
     } else {
       test_filter = $('select[name="subset_test_defs"]').val();
     }
-  } else if ($('#rdm-tests-selection-previously_failed').attr('checked')) {
+  } else if ($('#rdm-tests-selection-previously_failed').prop('checked')) {
     if ($('select[name="failed_test_defs"]').val() == null) {
       rdmtests.display_dialog_message(
         'Error',
@@ -832,7 +832,7 @@ RDMTests.prototype.collect_data = function() {
   this.query_server(
       '/RunCollector',
       { 'u': $('#publisher-universe-list').val(),
-        'skip_queued': $('#publisher-skip-queued-messages').attr('checked') ?  true : false,
+        'skip_queued': $('#publisher-skip-queued-messages').prop('checked') ?  true : false,
       },
       function(data) {
         window.setTimeout(function() { rdmtests.stat_collector(); },
